==> cljs-emotion-2021-02-14.0.0.jar: public/js/devcards/cljs-runtime/dv.cljs_emotion.js <==
goog.provide('dv.cljs_emotion');
var module$node_modules$react$index=shadow.js.require("module$node_modules$react$index", {});
var module$node_modules$$emotion$hash$dist$hash_browser_cjs=shadow.js.require("module$node_modules$$emotion$hash$dist$hash_browser_cjs", {});
var module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs=shadow.js.require("module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs", {});
var module$node_modules$$emotion$react$dist$emotion_react_browser_cjs=shadow.js.require("module$node_modules$$emotion$react$dist$emotion_react_browser_cjs", {});
dv.cljs_emotion.emotion_hash = goog.object.get(module$node_modules$$emotion$hash$dist$hash_browser_cjs,"default");
dv.cljs_emotion.styled_STAR_ = goog.object.get(module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs,"default");
/**
 * Utility function that will force a lazy sequence of children (recursively) into realized
 *   vectors (React cannot deal with lazy seqs in production mode)
 */
dv.cljs_emotion.force_children = (function dv$cljs_emotion$force_children(x){
if(cljs.core.seq_QMARK_(x)){
return cljs.core.to_array(cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(dv.cljs_emotion.force_children,x));
} else {
return x;
}
});
dv.cljs_emotion.keyframes = (function dv$cljs_emotion$keyframes(anim_map){
return module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.keyframes(cljs.core.clj__GT_js(anim_map));
});
dv.cljs_emotion.kebab__GT_camel = (function dv$cljs_emotion$kebab__GT_camel(prop){
if(clojure.string.starts_with_QMARK_(prop,".")){
return prop;
} else {
if(clojure.string.includes_QMARK_(prop,"-")){
var words = cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(clojure.string.capitalize,cljs.core.re_seq(/[a-zA-Z]+/,prop));
return clojure.string.join.cljs$core$IFn$_invoke$arity$1(cljs.core.update.cljs$core$IFn$_invoke$arity$3(words,(0),clojure.string.lower_case));
} else {
return prop;
}
}
});
/**
 * Also replaces styled components with their css classname is key position.
 */
dv.cljs_emotion.camelize_keys = (function dv$cljs_emotion$camelize_keys(style_map){
return clojure.walk.postwalk((function dv$cljs_emotion$camelize_keys_$_in_walk(v){
if((v instanceof cljs.core.Keyword)){
return dv.cljs_emotion.kebab__GT_camel(cljs.core.name(v));
} else {
if(cljs.core.truth_((function (){var and__4115__auto__ = cljs.core.meta(v);
if(cljs.core.truth_(and__4115__auto__)){
return cljs.core.contains_QMARK_(cljs.core.meta(v),new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661));
} else {
return and__4115__auto__;
}
})())){
return [".",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661).cljs$core$IFn$_invoke$arity$1(cljs.core.meta(v)))].join('');
} else {
return v;

}
}
}),style_map);
});
/**
 * @define {string}
 */
dv.cljs_emotion.ADD_CLASSNAMES = goog.define("dv.cljs_emotion.ADD_CLASSNAMES","INITIAL");
dv.cljs_emotion.add_class_names_QMARK_ = (function dv$cljs_emotion$add_class_names_QMARK_(){
if(cljs.core.boolean_QMARK_(dv.cljs_emotion.ADD_CLASSNAMES)){
return dv.cljs_emotion.ADD_CLASSNAMES;
} else {
return goog.DEBUG;
}
});
dv.cljs_emotion.add_class_name = (function dv$cljs_emotion$add_class_name(props,class_name){
if(cljs.core.object_QMARK_(props)){
var G__142209 = props;
goog.object.set(G__142209,"className",clojure.string.trim(clojure.string.join.cljs$core$IFn$_invoke$arity$2(" ",new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [class_name,goog.object.get(props,"className")], null))));

return G__142209;
} else {
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(props,new cljs.core.Keyword(null,"className","className",-1983287057),(function (p1__142208_SHARP_){
if((p1__142208_SHARP_ == null)){
return class_name;
} else {
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(class_name)," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(p1__142208_SHARP_)].join('');
}
}));
}
});
dv.cljs_emotion.hashit = (function dv$cljs_emotion$hashit(string){
return ["dvcss-",cljs.core.str.cljs$core$IFn$_invoke$arity$1((dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1 ? dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1(string) : dv.cljs_emotion.emotion_hash.call(null,string)))].join('');
});
dv.cljs_emotion.set_class_name = (function dv$cljs_emotion$set_class_name(props,class_name){
if(cljs.core.truth_(class_name)){
var hashed_name = dv.cljs_emotion.hashit(class_name);
var props__$1 = dv.cljs_emotion.add_class_name(props,hashed_name);
if(cljs.core.truth_(dv.cljs_emotion.add_class_names_QMARK_())){
return dv.cljs_emotion.add_class_name(props__$1,class_name);
} else {
return props__$1;
}
} else {
return props;
}
});
dv.cljs_emotion.react_factory = (function dv$cljs_emotion$react_factory(el,class_name){
return (function() {
var G__142217 = null;
var G__142217__0 = (function (){
return module$node_modules$react$index.createElement(el,cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(cljs.core.PersistentArrayMap.EMPTY,class_name)));
});
var G__142217__1 = (function (props){
try{if(cljs.core.truth_((function (){var or__4126__auto__ = module$node_modules$react$index.isValidElement(props);
if(cljs.core.truth_(or__4126__auto__)){
return or__4126__auto__;
} else {
return typeof props === 'string';
}
})())){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),props);
} else {
if(cljs.core.map_QMARK_(props)){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
return module$node_modules$react$index.createElement(el,props__$1);
} else {
if(cljs.core.object_QMARK_(props)){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(props,class_name));
} else {
if(((cljs.core.array_QMARK_(props)) || (cljs.core.coll_QMARK_(props)))){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(props));
} else {
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name));

}
}
}
}
}catch (e142211){if((e142211 instanceof Object)){
var e = e142211;
return console.error("Error invoking an emotion styled component: ",e);
} else {
throw e142211;

}
}});
var G__142217__2 = (function() { 
var G__142218__delegate = function (props,children){
if(((((cljs.core.object_QMARK_(props)) && (cljs.core.not(module$node_modules$react$index.isValidElement(props))))) || (cljs.core.map_QMARK_(props)))){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
if(cljs.core.seq(children)){
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,props__$1,dv.cljs_emotion.force_children(children));
} else {
return module$node_modules$react$index.createElement(el,props__$1);
}
} else {
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(cljs.core.list_STAR_.cljs$core$IFn$_invoke$arity$2(props,children)));
}
};
var G__142218 = function (props,var_args){
var children = null;
if (arguments.length > 1) {
var G__142219__i = 0, G__142219__a = new Array(arguments.length -  1);
while (G__142219__i < G__142219__a.length) {G__142219__a[G__142219__i] = arguments[G__142219__i + 1]; ++G__142219__i;}
  children = new cljs.core.IndexedSeq(G__142219__a,0,null);
} 
return G__142218__delegate.call(this,props,children);};
G__142218.cljs$lang$maxFixedArity = 1;
G__142218.cljs$lang$applyTo = (function (arglist__142220){
var props = cljs.core.first(arglist__142220);
var children = cljs.core.rest(arglist__142220);
return G__142218__delegate(props,children);
});
G__142218.cljs$core$IFn$_invoke$arity$variadic = G__142218__delegate;
return G__142218;
})()
;
G__142217 = function(props,var_args){
var children = var_args;
switch(arguments.length){
case 0:
return G__142217__0.call(this);
case 1:
return G__142217__1.call(this,props);
default:
var G__142221 = null;
if (arguments.length > 1) {
var G__142222__i = 0, G__142222__a = new Array(arguments.length -  1);
while (G__142222__i < G__142222__a.length) {G__142222__a[G__142222__i] = arguments[G__142222__i + 1]; ++G__142222__i;}
G__142221 = new cljs.core.IndexedSeq(G__142222__a,0,null);
}
return G__142217__2.cljs$core$IFn$_invoke$arity$variadic(props, G__142221);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__142217.cljs$lang$maxFixedArity = 1;
G__142217.cljs$lang$applyTo = G__142217__2.cljs$lang$applyTo;
G__142217.cljs$core$IFn$_invoke$arity$0 = G__142217__0;
G__142217.cljs$core$IFn$_invoke$arity$1 = G__142217__1;
G__142217.cljs$core$IFn$_invoke$arity$variadic = G__142217__2.cljs$core$IFn$_invoke$arity$variadic;
return G__142217;
})()
});
dv.cljs_emotion.global_STAR_ = dv.cljs_emotion.react_factory(module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.Global,null);
dv.cljs_emotion.global_style = (function dv$cljs_emotion$global_style(props){
return dv.cljs_emotion.global_STAR_(new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"styles","styles",1954480375),dv.cljs_emotion.camelize_keys(props)], null));
});
dv.cljs_emotion.theme_provider = (function dv$cljs_emotion$theme_provider(var_args){
var args__4742__auto__ = [];
var len__4736__auto___142223 = arguments.length;
var i__4737__auto___142224 = (0);
while(true){
if((i__4737__auto___142224 < len__4736__auto___142223)){
args__4742__auto__.push((arguments[i__4737__auto___142224]));

var G__142225 = (i__4737__auto___142224 + (1));
i__4737__auto___142224 = G__142225;
continue;
} else {
}
break;
}

var argseq__4743__auto__ = ((((1) < args__4742__auto__.length))?(new cljs.core.IndexedSeq(args__4742__auto__.slice((1)),(0),null)):null);
return dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4743__auto__);
});

(dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic = (function (props,children){
if(cljs.core.contains_QMARK_(props,new cljs.core.Keyword(null,"theme","theme",-1247880880))){
} else {
throw (new Error("You must pass a :theme to the theme-provider."));
}

return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.ThemeProvider,cljs.core.clj__GT_js(props),dv.cljs_emotion.force_children(children));
}));

(dv.cljs_emotion.theme_provider.cljs$lang$maxFixedArity = (1));

/** @this {Function} */
(dv.cljs_emotion.theme_provider.cljs$lang$applyTo = (function (seq142213){
var G__142214 = cljs.core.first(seq142213);
var seq142213__$1 = cljs.core.next(seq142213);
var self__4723__auto__ = this;
return self__4723__auto__.cljs$core$IFn$_invoke$arity$variadic(G__142214,seq142213__$1);
}));


//# sourceMappingURL=dv.cljs_emotion.js.map

==> cljs-emotion-2021-02-15.0.0.jar: public/js/devcards/cljs-runtime/dv.cljs_emotion.js <==
goog.provide('dv.cljs_emotion');
var module$node_modules$react$index=shadow.js.require("module$node_modules$react$index", {});
var module$node_modules$$emotion$hash$dist$hash_browser_cjs=shadow.js.require("module$node_modules$$emotion$hash$dist$hash_browser_cjs", {});
var module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs=shadow.js.require("module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs", {});
var module$node_modules$$emotion$react$dist$emotion_react_browser_cjs=shadow.js.require("module$node_modules$$emotion$react$dist$emotion_react_browser_cjs", {});
dv.cljs_emotion.emotion_hash = goog.object.get(module$node_modules$$emotion$hash$dist$hash_browser_cjs,"default");
dv.cljs_emotion.styled_STAR_ = goog.object.get(module$node_modules$$emotion$styled$dist$emotion_styled_browser_cjs,"default");
/**
 * Utility function that will force a lazy sequence of children (recursively) into realized
 *   vectors (React cannot deal with lazy seqs in production mode)
 */
dv.cljs_emotion.force_children = (function dv$cljs_emotion$force_children(x){
if(cljs.core.seq_QMARK_(x)){
return cljs.core.to_array(cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(dv.cljs_emotion.force_children,x));
} else {
return x;
}
});
dv.cljs_emotion.keyframes = (function dv$cljs_emotion$keyframes(anim_map){
return module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.keyframes(cljs.core.clj__GT_js(anim_map));
});
dv.cljs_emotion.kebab__GT_camel = (function dv$cljs_emotion$kebab__GT_camel(prop){
if(clojure.string.starts_with_QMARK_(prop,".")){
return prop;
} else {
if(clojure.string.includes_QMARK_(prop,"-")){
var words = cljs.core.mapv.cljs$core$IFn$_invoke$arity$2(clojure.string.capitalize,cljs.core.re_seq(/[a-zA-Z]+/,prop));
return clojure.string.join.cljs$core$IFn$_invoke$arity$1(cljs.core.update.cljs$core$IFn$_invoke$arity$3(words,(0),clojure.string.lower_case));
} else {
return prop;
}
}
});
/**
 * Also replaces styled components with their css classname is key position.
 */
dv.cljs_emotion.camelize_keys = (function dv$cljs_emotion$camelize_keys(style_map){
return clojure.walk.postwalk((function dv$cljs_emotion$camelize_keys_$_in_walk(v){
if((v instanceof cljs.core.Keyword)){
return dv.cljs_emotion.kebab__GT_camel(cljs.core.name(v));
} else {
if(cljs.core.truth_((function (){var and__4115__auto__ = cljs.core.meta(v);
if(cljs.core.truth_(and__4115__auto__)){
return cljs.core.contains_QMARK_(cljs.core.meta(v),new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661));
} else {
return and__4115__auto__;
}
})())){
return [".",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword("dv.cljs-emotion","hashed-name","dv.cljs-emotion/hashed-name",-795044661).cljs$core$IFn$_invoke$arity$1(cljs.core.meta(v)))].join('');
} else {
return v;

}
}
}),style_map);
});
/**
 * @define {string}
 */
dv.cljs_emotion.ADD_CLASSNAMES = goog.define("dv.cljs_emotion.ADD_CLASSNAMES","INITIAL");
dv.cljs_emotion.add_class_names_QMARK_ = (function dv$cljs_emotion$add_class_names_QMARK_(){
if(cljs.core.boolean_QMARK_(dv.cljs_emotion.ADD_CLASSNAMES)){
return dv.cljs_emotion.ADD_CLASSNAMES;
} else {
return goog.DEBUG;
}
});
dv.cljs_emotion.add_class_name = (function dv$cljs_emotion$add_class_name(props,class_name){
if(cljs.core.object_QMARK_(props)){
var G__63224 = props;
goog.object.set(G__63224,"className",clojure.string.trim(clojure.string.join.cljs$core$IFn$_invoke$arity$2(" ",new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [class_name,goog.object.get(props,"className")], null))));

return G__63224;
} else {
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(props,new cljs.core.Keyword(null,"className","className",-1983287057),(function (p1__63223_SHARP_){
if((p1__63223_SHARP_ == null)){
return class_name;
} else {
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(class_name)," ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(p1__63223_SHARP_)].join('');
}
}));
}
});
dv.cljs_emotion.hashit = (function dv$cljs_emotion$hashit(string){
return ["dvcss-",cljs.core.str.cljs$core$IFn$_invoke$arity$1((dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1 ? dv.cljs_emotion.emotion_hash.cljs$core$IFn$_invoke$arity$1(string) : dv.cljs_emotion.emotion_hash.call(null,string)))].join('');
});
dv.cljs_emotion.set_class_name = (function dv$cljs_emotion$set_class_name(props,class_name){
if(cljs.core.truth_(class_name)){
var hashed_name = dv.cljs_emotion.hashit(class_name);
var props__$1 = dv.cljs_emotion.add_class_name(props,hashed_name);
if(cljs.core.truth_(dv.cljs_emotion.add_class_names_QMARK_())){
return dv.cljs_emotion.add_class_name(props__$1,class_name);
} else {
return props__$1;
}
} else {
return props;
}
});
dv.cljs_emotion.react_factory = (function dv$cljs_emotion$react_factory(el,class_name){
return (function() {
var G__63234 = null;
var G__63234__0 = (function (){
return module$node_modules$react$index.createElement(el,cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(cljs.core.PersistentArrayMap.EMPTY,class_name)));
});
var G__63234__1 = (function (props){
try{if(cljs.core.truth_((function (){var or__4126__auto__ = module$node_modules$react$index.isValidElement(props);
if(cljs.core.truth_(or__4126__auto__)){
return or__4126__auto__;
} else {
return typeof props === 'string';
}
})())){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),props);
} else {
if(cljs.core.map_QMARK_(props)){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
return module$node_modules$react$index.createElement(el,props__$1);
} else {
if(cljs.core.object_QMARK_(props)){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(props,class_name));
} else {
if(((cljs.core.array_QMARK_(props)) || (cljs.core.coll_QMARK_(props)))){
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(props));
} else {
return module$node_modules$react$index.createElement(el,dv.cljs_emotion.set_class_name(({}),class_name));

}
}
}
}
}catch (e63225){if((e63225 instanceof Object)){
var e = e63225;
return console.error("Error invoking an emotion styled component: ",e);
} else {
throw e63225;

}
}});
var G__63234__2 = (function() { 
var G__63236__delegate = function (props,children){
if(((((cljs.core.object_QMARK_(props)) && (cljs.core.not(module$node_modules$react$index.isValidElement(props))))) || (cljs.core.map_QMARK_(props)))){
var props__$1 = cljs.core.clj__GT_js(dv.cljs_emotion.set_class_name(props,class_name));
if(cljs.core.seq(children)){
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,props__$1,dv.cljs_emotion.force_children(children));
} else {
return module$node_modules$react$index.createElement(el,props__$1);
}
} else {
return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,el,dv.cljs_emotion.set_class_name(({}),class_name),dv.cljs_emotion.force_children(cljs.core.list_STAR_.cljs$core$IFn$_invoke$arity$2(props,children)));
}
};
var G__63236 = function (props,var_args){
var children = null;
if (arguments.length > 1) {
var G__63238__i = 0, G__63238__a = new Array(arguments.length -  1);
while (G__63238__i < G__63238__a.length) {G__63238__a[G__63238__i] = arguments[G__63238__i + 1]; ++G__63238__i;}
  children = new cljs.core.IndexedSeq(G__63238__a,0,null);
} 
return G__63236__delegate.call(this,props,children);};
G__63236.cljs$lang$maxFixedArity = 1;
G__63236.cljs$lang$applyTo = (function (arglist__63239){
var props = cljs.core.first(arglist__63239);
var children = cljs.core.rest(arglist__63239);
return G__63236__delegate(props,children);
});
G__63236.cljs$core$IFn$_invoke$arity$variadic = G__63236__delegate;
return G__63236;
})()
;
G__63234 = function(props,var_args){
var children = var_args;
switch(arguments.length){
case 0:
return G__63234__0.call(this);
case 1:
return G__63234__1.call(this,props);
default:
var G__63240 = null;
if (arguments.length > 1) {
var G__63241__i = 0, G__63241__a = new Array(arguments.length -  1);
while (G__63241__i < G__63241__a.length) {G__63241__a[G__63241__i] = arguments[G__63241__i + 1]; ++G__63241__i;}
G__63240 = new cljs.core.IndexedSeq(G__63241__a,0,null);
}
return G__63234__2.cljs$core$IFn$_invoke$arity$variadic(props, G__63240);
}
throw(new Error('Invalid arity: ' + arguments.length));
};
G__63234.cljs$lang$maxFixedArity = 1;
G__63234.cljs$lang$applyTo = G__63234__2.cljs$lang$applyTo;
G__63234.cljs$core$IFn$_invoke$arity$0 = G__63234__0;
G__63234.cljs$core$IFn$_invoke$arity$1 = G__63234__1;
G__63234.cljs$core$IFn$_invoke$arity$variadic = G__63234__2.cljs$core$IFn$_invoke$arity$variadic;
return G__63234;
})()
});
dv.cljs_emotion.global_STAR_ = dv.cljs_emotion.react_factory(module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.Global,null);
dv.cljs_emotion.global_style = (function dv$cljs_emotion$global_style(props){
return dv.cljs_emotion.global_STAR_(new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"styles","styles",1954480375),dv.cljs_emotion.camelize_keys(props)], null));
});
dv.cljs_emotion.theme_provider = (function dv$cljs_emotion$theme_provider(var_args){
var args__4742__auto__ = [];
var len__4736__auto___63247 = arguments.length;
var i__4737__auto___63248 = (0);
while(true){
if((i__4737__auto___63248 < len__4736__auto___63247)){
args__4742__auto__.push((arguments[i__4737__auto___63248]));

var G__63249 = (i__4737__auto___63248 + (1));
i__4737__auto___63248 = G__63249;
continue;
} else {
}
break;
}

var argseq__4743__auto__ = ((((1) < args__4742__auto__.length))?(new cljs.core.IndexedSeq(args__4742__auto__.slice((1)),(0),null)):null);
return dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__4743__auto__);
});

(dv.cljs_emotion.theme_provider.cljs$core$IFn$_invoke$arity$variadic = (function (props,children){
if(cljs.core.contains_QMARK_(props,new cljs.core.Keyword(null,"theme","theme",-1247880880))){
} else {
throw (new Error("You must pass a :theme to the theme-provider."));
}

return cljs.core.apply.cljs$core$IFn$_invoke$arity$4(module$node_modules$react$index.createElement,module$node_modules$$emotion$react$dist$emotion_react_browser_cjs.ThemeProvider,cljs.core.clj__GT_js(props),dv.cljs_emotion.force_children(children));
}));

(dv.cljs_emotion.theme_provider.cljs$lang$maxFixedArity = (1));

/** @this {Function} */
(dv.cljs_emotion.theme_provider.cljs$lang$applyTo = (function (seq63227){
var G__63228 = cljs.core.first(seq63227);
var seq63227__$1 = cljs.core.next(seq63227);
var self__4723__auto__ = this;
return self__4723__auto__.cljs$core$IFn$_invoke$arity$variadic(G__63228,seq63227__$1);
}));


//# sourceMappingURL=dv.cljs_emotion.js.map
